==> is_firebase_test_lab_activated-1.0.1.tar.gz: android/src/main/kotlin/com/ricardorb/is_firebase_test_lab_activated/IsFirebaseTestLabActivatedPlugin.kt <==
package com.ricardorb.is_firebase_test_lab_activated

import android.provider.Settings
import androidx.annotation.NonNull
import io.flutter.embedding.engine.plugins.FlutterPlugin
import io.flutter.plugin.common.MethodCall
import io.flutter.plugin.common.MethodChannel
import io.flutter.plugin.common.MethodChannel.MethodCallHandler

/** IsFirebaseTestLabActivatedPlugin */
class IsFirebaseTestLabActivatedPlugin : FlutterPlugin, MethodCallHandler {
    /// The MethodChannel that will the communication between Flutter and native Android
    ///
    /// This local reference serves to register the plugin with the Flutter Engine and unregister it
    /// when the Flutter Engine is detached from the Activity
    private lateinit var channel: MethodChannel

    override fun onAttachedToEngine(@NonNull flutterPluginBinding: FlutterPlugin.FlutterPluginBinding) {
        channel = MethodChannel(flutterPluginBinding.binaryMessenger, "is_firebase_test_lab_activated")
        channel.setMethodCallHandler(this)
    }

    override fun onMethodCall(@NonNull call: MethodCall, @NonNull result: Result) {
        if (call.method == "isFirebaseTestLabActivated") {
            val testLabSetting: String = Settings.System.getString(context.getContentResolver(), "firebase.test.lab")
            result.success("true" == testLabSetting)
        } else {
            result.notImplemented()
        }
    }

    override fun onDetachedFromEngine(@NonNull binding: FlutterPlugin.FlutterPluginBinding) {
        channel.setMethodCallHandler(null)
    }
}

==> is_firebase_test_lab_activated-2.0.1.tar.gz: android/src/main/kotlin/com/ricardorb/is_firebase_test_lab_activated/IsFirebaseTestLabActivatedPlugin.kt <==
package com.ricardorb.is_firebase_test_lab_activated

import android.provider.Settings
import androidx.annotation.NonNull
import io.flutter.embedding.engine.plugins.FlutterPlugin
import io.flutter.plugin.common.MethodCall
import io.flutter.plugin.common.MethodChannel
import io.flutter.plugin.common.MethodChannel.MethodCallHandler

/** IsFirebaseTestLabActivatedPlugin */
class IsFirebaseTestLabActivatedPlugin : FlutterPlugin, MethodCallHandler {

    private lateinit var channel: MethodChannel
    private var isFirebaseTestLabActivated: Boolean? = null

    override fun onAttachedToEngine(@NonNull flutterPluginBinding: FlutterPlugin.FlutterPluginBinding) {
        if (isFirebaseTestLabActivated == null) {
            val testLabSetting: String? = Settings.System.getString(flutterPluginBinding.applicationContext.contentResolver, "firebase.test.lab")
            isFirebaseTestLabActivated = "true" == testLabSetting
        }
        channel = MethodChannel(flutterPluginBinding.binaryMessenger, "is_firebase_test_lab_activated")
        channel.setMethodCallHandler(this)
    }

    override fun onMethodCall(@NonNull call: MethodCall, @NonNull result: MethodChannel.Result) {
        if (call.method == "isFirebaseTestLabActivated") {
            result.success(isFirebaseTestLabActivated)
        } else {
            result.notImplemented()
        }
    }

    override fun onDetachedFromEngine(@NonNull binding: FlutterPlugin.FlutterPluginBinding) {
        channel.setMethodCallHandler(null)
    }
}
